@@ -26,10 +26,11 @@ from telegram_payment_bot.auth_user.authorized_users_list import AuthorizedUsers
 from telegram_payment_bot.bot.bot_config import BotConfigTypes
 from telegram_payment_bot.command.command_base import CommandBase
 from telegram_payment_bot.command.command_data import CommandParameterError
+from telegram_payment_bot.email.smtp_emailer import SmtpEmailerError
 from telegram_payment_bot.member.members_kicker import MembersKicker
 from telegram_payment_bot.member.members_payment_getter import MembersPaymentGetter
 from telegram_payment_bot.member.members_username_getter import MembersUsernameGetter
-from telegram_payment_bot.misc.chat_members import ChatMembersGetter
+from telegram_payment_bot.misc.chat_members import ChatMembersList, ChatMembersGetter
 from telegram_payment_bot.misc.helpers import ChatHelper, UserHelper
 from telegram_payment_bot.payment.payments_check_scheduler import (
     PaymentsCheckJobAlreadyRunningError, PaymentsCheckJobNotRunningError, PaymentsCheckJobInvalidPeriodError,
@@ -38,7 +39,6 @@ from telegram_payment_bot.payment.payments_check_scheduler import (
 from telegram_payment_bot.payment.payments_data import PaymentErrorTypes
 from telegram_payment_bot.payment.payments_emailer import PaymentsEmailer
 from telegram_payment_bot.payment.payments_loader_factory import PaymentsLoaderFactory
-from telegram_payment_bot.email.smtp_emailer import SmtpEmailerError
 from telegram_payment_bot._version import __version__
 
 
@@ -264,10 +264,20 @@ class RemoveNoUsernameCmd(CommandBase):
                                         chat_title=ChatHelper.GetTitle(self.cmd_data.Chat()))
         )
 
-        # Kick members if any
-        kicked_members = MembersKicker(self.client,
-                                       self.config,
-                                       self.logger).KickAllWithNoUsername(self.cmd_data.Chat())
+        finished = False
+        kicked_members = ChatMembersList()
+        # Continue until all members have been kicked
+        # Useful in channels when at maximum 200 members can be kicked at once
+        while not finished:
+            curr_kicked_members = MembersKicker(self.client,
+                                                self.config,
+                                                self.logger).KickAllWithNoUsername(self.cmd_data.Chat())
+            if curr_kicked_members.Any():
+                kicked_members.AddMultiple(curr_kicked_members)
+                # Stop if test mode to avoid infinite looping (members are not really kicked in test mode)
+                finished = self.config.GetValue(BotConfigTypes.APP_TEST_MODE)
+            else:
+                finished = True
 
         # Build message
         msg = self.translator.GetSentence("REMOVE_NO_USERNAME_COMPLETED_CMD",
@@ -485,10 +495,20 @@ class RemoveNoPaymentCmd(CommandBase):
                                         chat_title=ChatHelper.GetTitle(self.cmd_data.Chat()))
         )
 
-        # Kick members if any
-        kicked_members = MembersKicker(self.client,
-                                       self.config,
-                                       self.logger).KickAllWithExpiredPayment(self.cmd_data.Chat())
+        finished = False
+        kicked_members = ChatMembersList()
+        # Continue until all members have been kicked
+        # Useful in channels when at maximum 200 members can be kicked at once
+        while not finished:
+            curr_kicked_members = MembersKicker(self.client,
+                                                self.config,
+                                                self.logger).KickAllWithExpiredPayment(self.cmd_data.Chat())
+            if curr_kicked_members.Any():
+                kicked_members.AddMultiple(curr_kicked_members)
+                # Stop if test mode to avoid infinite looping (members are not really kicked in test mode)
+                finished = self.config.GetValue(BotConfigTypes.APP_TEST_MODE)
+            else:
+                finished = True
 
         # Build message
         msg = self.translator.GetSentence("REMOVE_NO_PAYMENT_COMPLETED_CMD",
